@@ -20,6 +20,8 @@ from devshell.modules.fedorahostedgitport import FedoraHostedGitPort
 
 class AutoToolsBuilder(object): pass
 
-class FedoraHostedGitPort(FedoraHostedGitPort):
+class RevisorPort(FedoraHostedGitPort):
     builder = AutoToolsBuilder
     
+
+__all__ = ['AutoToolsBuilder', 'RevisorPort']
